==> python-synologydsm-api_2.7.1.orig.tar.gz: py-synologydsm-api-2.7.1/tests/api_data/dsm_7/core/const_7_core_external_usb.py <==
"""DSM 7 SYNO.Core.ExternalDevice.Storage.USB data."""

DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_NO_EXTERNAL_USB = {
    "data": {"devices": []},
    "success": True,
}
DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_EXTERNAL_USB = {
    "data": {
        "devices": [
            {
                "dev_id": "usb1",
                "dev_title": "USB Disk 1",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ntfs",
                        "filesystem": "ntfs",
                        "name_id": "usb1p1",
                        "partition_title": "USB Disk 1 Partition 1",
                        "share_name": "usbshare1-1",
                        "status": "normal",
                        "total_size_mb": 1024,
                        "used_size_mb": 10,
                    },
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb1p2",
                        "partition_title": "USB Disk 1 Partition 2",
                        "share_name": "usbshare1-2",
                        "status": "normal",
                        "total_size_mb": 1024,
                        "used_size_mb": 0,
                    },
                ],
                "producer": "PNY",
                "product": "Flash Drive",
                "progress": "",
                "status": "normal",
                "total_size_mb": 122070,
            },
            {
                "dev_id": "usb2",
                "dev_title": "USB Disk 2",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ext4",
                        "filesystem": "ext4",
                        "name_id": "usb2p1",
                        "partition_title": "USB Disk 2 Partition 1",
                        "share_name": "usbshare2",
                        "status": "normal",
                        "total_size_mb": 15138295,
                        "used_size_mb": 10899326,
                    }
                ],
                "producer": "Western Digital Technologies, Inc.",
                "product": "easystore 264D",
                "progress": "",
                "status": "normal",
                "total_size_mb": 15259648,
            },
            {
                "dev_id": "usb3",
                "dev_title": "USB Disk 3",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb3p1",
                        "partition_title": "USB Disk 3 Partition 1",
                        "share_name": "usbshare3-1",
                        "status": "normal",
                        "total_size_mb": 197,
                        "used_size_mb": 10,
                    },
                    {
                        "dev_fstype": "hfsplus",
                        "filesystem": "hfsplus",
                        "name_id": "usb3p2",
                        "partition_title": "USB Disk 3 Partition 2",
                        "share_name": "usbshare3-2",
                        "status": "normal",
                        "total_size_mb": 117020,
                        "used_size_mb": 13965,
                    },
                ],
                "producer": "SanDisk Corp.",
                "product": " SanDisk 3.2Gen1",
                "progress": "",
                "status": "normal",
                "total_size_mb": 117348,
            },
            {
                "dev_id": "usb4",
                "dev_title": "USB Disk 4",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "exfat",
                        "filesystem": "exfat",
                        "name_id": "usb4p1",
                        "partition_title": "USB Disk 4 Partition 1",
                        "share_name": "usbshare4",
                        "status": "normal",
                        "total_size_mb": 241397,
                        "used_size_mb": 1,
                    }
                ],
                "producer": "PNY",
                "product": "USB 3.0 FD",
                "progress": "",
                "status": "normal",
                "total_size_mb": 241408,
            },
            {
                "dev_id": "usb5",
                "dev_title": "USB Disk 5",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb5p1",
                        "partition_title": "USB Disk 5 Partition 1",
                        "share_name": "usbshare5-1",
                        "status": "normal",
                        "total_size_mb": 3886,
                        "used_size_mb": 0,
                    },
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb5p2",
                        "partition_title": "USB Disk 5 Partition 2",
                        "share_name": "usbshare5-2",
                        "status": "normal",
                        "total_size_mb": 32,
                        "used_size_mb": 27,
                    },
                ],
                "producer": "SanDisk Corp.",
                "product": "Cruzer Titanium+",
                "progress": "",
                "status": "normal",
                "total_size_mb": 3919,
            },
            {
                "dev_id": "usb6",
                "dev_title": "USB Disk 6",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ntfs",
                        "filesystem": "ntfs",
                        "name_id": "usb6p1",
                        "partition_title": "USB Disk 6 Partition 1",
                        "share_name": "usbshare6",
                        "status": "normal",
                        "total_size_mb": 715371,
                        "used_size_mb": 203585,
                    }
                ],
                "producer": "Western Digital Technologies, Inc.",
                "product": "My Passport Essential (WDBACY)",
                "progress": "",
                "status": "normal",
                "total_size_mb": 715372,
            },
            {
                "dev_id": "usb8",
                "dev_title": "USB Disk 8",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "unknown",
                        "filesystem": "",
                        "name_id": "usb8",
                        "partition_title": "USB Disk 8",
                        "share_name": "",
                        "status": "normal",
                        "total_size_mb": "",
                    }
                ],
                "producer": "Genesys Logic, Inc.",
                "product": "All-in-One Cardreader",
                "progress": "",
                "status": "normal",
                "total_size_mb": 29,
            },
        ]
    },
    "success": True,
}

==> python-synologydsm-api_2.7.3.orig.tar.gz: py-synologydsm-api-2.7.3/tests/api_data/dsm_7/core/const_7_core_external_usb.py <==
"""DSM 7 SYNO.Core.ExternalDevice.Storage.USB data."""

DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_NO_EXTERNAL_USB = {
    "data": {"devices": []},
    "success": True,
}
DSM_7_CORE_EXTERNAL_USB_DS1821_PLUS_EXTERNAL_USB = {
    "data": {
        "devices": [
            {
                "dev_id": "usb1",
                "dev_title": "USB Disk 1",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ntfs",
                        "filesystem": "ntfs",
                        "name_id": "usb1p1",
                        "partition_title": "USB Disk 1 Partition 1",
                        "share_name": "usbshare1-1",
                        "status": "normal",
                        "total_size_mb": 1024,
                        "used_size_mb": 10,
                    },
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb1p2",
                        "partition_title": "USB Disk 1 Partition 2",
                        "share_name": "usbshare1-2",
                        "status": "normal",
                        "total_size_mb": 1024,
                        "used_size_mb": 0,
                    },
                ],
                "producer": "PNY",
                "product": "Flash Drive",
                "progress": "",
                "status": "normal",
                "total_size_mb": 122070,
            },
            {
                "dev_id": "usb2",
                "dev_title": "USB Disk 2",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ext4",
                        "filesystem": "ext4",
                        "name_id": "usb2p1",
                        "partition_title": "USB Disk 2 Partition 1",
                        "share_name": "usbshare2",
                        "status": "normal",
                        "total_size_mb": 15138295,
                        "used_size_mb": 10899326,
                    }
                ],
                "producer": "Western Digital Technologies, Inc.",
                "product": "easystore 264D",
                "progress": "",
                "status": "normal",
                "total_size_mb": 15259648,
            },
            {
                "dev_id": "usb3",
                "dev_title": "USB Disk 3",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb3p1",
                        "partition_title": "USB Disk 3 Partition 1",
                        "share_name": "usbshare3-1",
                        "status": "normal",
                        "total_size_mb": 197,
                        "used_size_mb": 10,
                    },
                    {
                        "dev_fstype": "hfsplus",
                        "filesystem": "hfsplus",
                        "name_id": "usb3p2",
                        "partition_title": "USB Disk 3 Partition 2",
                        "share_name": "usbshare3-2",
                        "status": "normal",
                        "total_size_mb": 117020,
                        "used_size_mb": 13965,
                    },
                ],
                "producer": "SanDisk Corp.",
                "product": " SanDisk 3.2Gen1",
                "progress": "",
                "status": "normal",
                "total_size_mb": 117348,
            },
            {
                "dev_id": "usb4",
                "dev_title": "USB Disk 4",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "exfat",
                        "filesystem": "exfat",
                        "name_id": "usb4p1",
                        "partition_title": "USB Disk 4 Partition 1",
                        "share_name": "usbshare4",
                        "status": "normal",
                        "total_size_mb": 241397,
                        "used_size_mb": 1,
                    }
                ],
                "producer": "PNY",
                "product": "USB 3.0 FD",
                "progress": "",
                "status": "normal",
                "total_size_mb": 241408,
            },
            {
                "dev_id": "usb5",
                "dev_title": "USB Disk 5",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb5p1",
                        "partition_title": "USB Disk 5 Partition 1",
                        "share_name": "usbshare5-1",
                        "status": "normal",
                        "total_size_mb": 3886,
                        "used_size_mb": 0,
                    },
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "usb5p2",
                        "partition_title": "USB Disk 5 Partition 2",
                        "share_name": "usbshare5-2",
                        "status": "normal",
                        "total_size_mb": 32,
                        "used_size_mb": 27,
                    },
                ],
                "producer": "SanDisk Corp.",
                "product": "Cruzer Titanium+",
                "progress": "",
                "status": "normal",
                "total_size_mb": 3919,
            },
            {
                "dev_id": "usb6",
                "dev_title": "USB Disk 6",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ntfs",
                        "filesystem": "ntfs",
                        "name_id": "usb6p1",
                        "partition_title": "USB Disk 6 Partition 1",
                        "share_name": "usbshare6",
                        "status": "normal",
                        "total_size_mb": 715371,
                        "used_size_mb": 203585,
                    }
                ],
                "producer": "Western Digital Technologies, Inc.",
                "product": "My Passport Essential (WDBACY)",
                "progress": "",
                "status": "normal",
                "total_size_mb": 715372,
            },
            {
                "dev_id": "usb8",
                "dev_title": "USB Disk 8",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "unknown",
                        "filesystem": "",
                        "name_id": "usb8",
                        "partition_title": "USB Disk 8",
                        "share_name": "",
                        "status": "normal",
                        "total_size_mb": "",
                    }
                ],
                "producer": "Genesys Logic, Inc.",
                "product": "All-in-One Cardreader",
                "progress": "",
                "status": "normal",
                "total_size_mb": 29,
            },
            {
                "dev_id": "sdq",
                "dev_title": "SD Card 1",
                "dev_type": "sdCard",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "vfat",
                        "filesystem": "FAT32",
                        "name_id": "sdq1",
                        "partition_title": "SD Card 1 Partition 1",
                        "share_name": "SDKarte",
                        "status": "normal",
                        "total_size_mb": 1903,
                        "used_size_mb": 76,
                    }
                ],
                "producer": "Genesys Logic, Inc.",
                "progress": "",
                "status": "normal",
                "total_size_mb": 1903,
            },
            {
                "dev_id": "sds",
                "dev_title": "USB Disk 1",
                "dev_type": "usbDisk",
                "formatable": True,
                "partitions": [
                    {
                        "dev_fstype": "ntfs",
                        "filesystem": "ntfs",
                        "name_id": "sds1",
                        "partition_title": "USB Disk 1 Partition 1",
                        "share_name": "usbshare1",
                        "status": "usbbackup",
                        "total_size_mb": 953868,
                        "used_size_mb": 862289,
                    }
                ],
                "producer": "Iomega Corp.",
                "product": "Prestige Portable Hard Drive",
                "progress": "",
                "status": "usbbackup",
                "total_size_mb": 953869,
            },
        ]
    },
    "success": True,
}
